// Copyright (c) 2000-2009 Nokia Corporation and/or its subsidiary(-ies).
// All rights reserved.
// This component and the accompanying materials are made available
// under the terms of "Eclipse Public License v1.0"
// which accompanies this distribution, and is available
// at the URL "http://www.eclipse.org/legal/epl-v10.html".
//
// Initial Contributors:
// Nokia Corporation - initial contribution.
//
// Contributors:
//
// Description:
//
  
#include <e32std.h>

#ifndef EKA2
/** DLL entry point */
GLDEF_C TInt E32Dll(TDllReason/* aReason*/)	
	{
	return (KErrNone);
	}
#endif

EXPORT_C void DummyExport()
	{
	}

EXPORT_C void NullFunction1() {}
EXPORT_C void NullFunction2() {}
EXPORT_C void NullFunction3() {}
EXPORT_C void NullFunction4() {}
EXPORT_C void NullFunction5() {}
EXPORT_C void NullFunction6() {}
EXPORT_C void NullFunction7() {}
EXPORT_C void NullFunction8() {}
EXPORT_C void NullFunction9() {}
EXPORT_C void NullFunction10() {}
EXPORT_C void NullFunction11() {}
EXPORT_C void NullFunction12() {}
EXPORT_C void NullFunction13() {}
EXPORT_C void NullFunction14() {}
EXPORT_C void NullFunction15() {}
EXPORT_C void NullFunction16() {}
EXPORT_C void NullFunction17() {}
EXPORT_C void NullFunction18() {}
EXPORT_C void NullFunction19() {}
EXPORT_C void NullFunction20() {}
EXPORT_C void NullFunction21() {}
EXPORT_C void NullFunction22() {}
EXPORT_C void NullFunction23() {}
EXPORT_C void NullFunction24() {}
EXPORT_C void NullFunction25() {}
EXPORT_C void NullFunction26() {}
EXPORT_C void NullFunction27() {}
EXPORT_C void NullFunction28() {}
EXPORT_C void NullFunction29() {}
EXPORT_C void NullFunction30() {}
EXPORT_C void NullFunction31() {}
EXPORT_C void NullFunction32() {}
EXPORT_C void NullFunction33() {}
EXPORT_C void NullFunction34() {}
EXPORT_C void NullFunction35() {}
EXPORT_C void NullFunction36() {}
EXPORT_C void NullFunction37() {}
EXPORT_C void NullFunction38() {}
EXPORT_C void NullFunction39() {}
EXPORT_C void NullFunction40() {}
EXPORT_C void NullFunction41() {}
EXPORT_C void NullFunction42() {}
EXPORT_C void NullFunction43() {}
EXPORT_C void NullFunction44() {}
EXPORT_C void NullFunction45() {}
EXPORT_C void NullFunction46() {}
EXPORT_C void NullFunction47() {}
EXPORT_C void NullFunction48() {}
EXPORT_C void NullFunction49() {}
EXPORT_C void NullFunction50() {}
EXPORT_C void NullFunction51() {}
EXPORT_C void NullFunction52() {}
EXPORT_C void NullFunction53() {}
EXPORT_C void NullFunction54() {}
EXPORT_C void NullFunction55() {}
EXPORT_C void NullFunction56() {}
EXPORT_C void NullFunction57() {}
EXPORT_C void NullFunction58() {}
EXPORT_C void NullFunction59() {}
EXPORT_C void NullFunction60() {}
EXPORT_C void NullFunction61() {}
EXPORT_C void NullFunction62() {}
EXPORT_C void NullFunction63() {}
