EXPORTS
	?NullFunction1@@YAXXZ @ 1 NONAME ; void __cdecl NullFunction1(void)
	?NullFunction2@@YAXXZ @ 2 NONAME ; void __cdecl NullFunction2(void)
	??1CPushMessage@@UAE@XZ @ 3 NONAME ; public: virtual __thiscall CPushMessage::~CPushMessage(void)
	?NullFunction3@@YAXXZ @ 4 NONAME ; void __cdecl NullFunction3(void)
	?NullFunction4@@YAXXZ @ 5 NONAME ; void __cdecl NullFunction4(void)
	?NullFunction5@@YAXXZ @ 6 NONAME ; void __cdecl NullFunction5(void)
	?NullFunction6@@YAXXZ @ 7 NONAME ; void __cdecl NullFunction6(void)
	?NullFunction7@@YAXXZ @ 8 NONAME ; void __cdecl NullFunction7(void)
	?NullFunction8@@YAXXZ @ 9 NONAME ; void __cdecl NullFunction8(void)
	?NullFunction9@@YAXXZ @ 10 NONAME ; void __cdecl NullFunction9(void)
	?NullFunction10@@YAXXZ @ 11 NONAME ; void __cdecl NullFunction10(void)
	?NullFunction11@@YAXXZ @ 12 NONAME ; void __cdecl NullFunction11(void)
	?NullFunction12@@YAXXZ @ 13 NONAME ; void __cdecl NullFunction12(void)
	?NullFunction13@@YAXXZ @ 14 NONAME ; void __cdecl NullFunction13(void)
	?DummyExport@@YAXXZ @ 15 NONAME ; void DummyExport(void)
	?NullFunction14@@YAXXZ @ 16 NONAME ; void __cdecl NullFunction14(void)
	?ExtractMultiOctetInteger@TWapBinCodex@@SAXABVTDesC8@@AAH@Z @ 17 NONAME ; public: static void __cdecl TWapBinCodex::ExtractMultiOctetInteger(class TDesC8 const &,int &)
	?ExtractUIntvarL@TWapBinCodex@@SAXABVTDesC8@@HAAVTUintvar@1@@Z @ 18 NONAME ; public: static void __cdecl TWapBinCodex::ExtractUIntvarL(class TDesC8 const &,int,class TWapBinCodex::TUintvar &)
	?NullFunction15@@YAXXZ @ 19 NONAME ; void __cdecl NullFunction15(void)
	?NullFunction16@@YAXXZ @ 20 NONAME ; void __cdecl NullFunction16(void)
	?NullFunction17@@YAXXZ @ 21 NONAME ; void __cdecl NullFunction17(void)
	?NullFunction18@@YAXXZ @ 22 NONAME ; void __cdecl NullFunction18(void)
	?NullFunction19@@YAXXZ @ 23 NONAME ; void __cdecl NullFunction19(void)
	?NullFunction20@@YAXXZ @ 24 NONAME ; void __cdecl NullFunction20(void)
	?GetAppID@CPushMessage@@QAEHAAVTPtrC8@@AAH1@Z @ 25 NONAME ; public: int __thiscall CPushMessage::GetAppID(class TPtrC8 &,int &,int &)
	?GetBinaryHeaderField@CPushMessage@@QBEHW4THttpHeaderField@@AAVTPtrC8@@@Z @ 26 NONAME ; public: int __thiscall CPushMessage::GetBinaryHeaderField(enum THttpHeaderField,class TPtrC8 &)const 
	?GetContentType@CPushMessage@@QBEXAAVTPtrC16@@@Z @ 27 NONAME ; public: void __thiscall CPushMessage::GetContentType(class TPtrC16 &)const 
	?NullFunction21@@YAXXZ @ 28 NONAME ; void __cdecl NullFunction21(void)
	?GetFilterPluginL@CWapPushFilterUtils@@SAPAVCWapPushMessageFilter@@XZ @ 29 NONAME ; public: static class CWapPushMessageFilter * __cdecl CWapPushFilterUtils::GetFilterPluginL(void)
	?GetHandlerL@PushAppDispatcher@@SAAAVCPushHandlerBase@@ABVTDesC8@@AAVMWapPushLog@@AAVMConnManObserver@@@Z @ 30 NONAME ; public: static class CPushHandlerBase & __cdecl PushAppDispatcher::GetHandlerL(class TDesC8 const &,class MWapPushLog &,class MConnManObserver &)
	?GetHandlerL@PushAppDispatcher@@SAAAVCPushHandlerBase@@HAAVMWapPushLog@@AAVMConnManObserver@@@Z @ 31 NONAME ; public: static class CPushHandlerBase & __cdecl PushAppDispatcher::GetHandlerL(int,class MWapPushLog &,class MConnManObserver &)
	?GetHandlerL@PushContentTypeDispatcher@@SAAAVCContentHandlerBase@@ABVTDesC16@@AAVMWapPushLog@@AAVMConnManObserver@@@Z @ 32 NONAME ; public: static class CContentHandlerBase & __cdecl PushContentTypeDispatcher::GetHandlerL(class TDesC16 const &,class MWapPushLog &,class MConnManObserver &)
	?GetHeader@CPushMessage@@QBEHAAVTPtrC8@@@Z @ 33 NONAME ; public: int __thiscall CPushMessage::GetHeader(class TPtrC8 &)const 
	?GetHeaderField@CPushMessage@@QBEHW4THttpHeaderField@@AAVTPtrC8@@@Z @ 34 NONAME ; public: int __thiscall CPushMessage::GetHeaderField(enum THttpHeaderField,class TPtrC8 &)const 
	?GetHeaderField@CPushMessage@@QBEHW4THttpHeaderField@@AAVTTime@@@Z @ 35 NONAME ; public: int __thiscall CPushMessage::GetHeaderField(enum THttpHeaderField,class TTime &)const 
	?NullFunction22@@YAXXZ @ 36 NONAME ; void __cdecl NullFunction22(void)
	?GetMessageBody@CPushMessage@@QBEHAAVTPtrC8@@@Z @ 37 NONAME ; public: int __thiscall CPushMessage::GetMessageBody(class TPtrC8 &)const 
	?NullFunction23@@YAXXZ @ 38 NONAME ; void __cdecl NullFunction23(void)
	?NullFunction24@@YAXXZ @ 39 NONAME ; void __cdecl NullFunction24(void)
	?NullFunction25@@YAXXZ @ 40 NONAME ; void __cdecl NullFunction25(void)
	?NullFunction26@@YAXXZ @ 41 NONAME ; void __cdecl NullFunction26(void)
	?NullFunction27@@YAXXZ @ 42 NONAME ; void __cdecl NullFunction27(void)
	?KillPushPlugin@CPluginKiller@@QAEXXZ @ 43 NONAME ; public: void __thiscall CPluginKiller::KillPushPlugin(void)
	?NullFunction28@@YAXXZ @ 44 NONAME ; void __cdecl NullFunction28(void)
	?NullFunction29@@YAXXZ @ 45 NONAME ; void __cdecl NullFunction29(void)
	?NullFunction30@@YAXXZ @ 46 NONAME ; void __cdecl NullFunction30(void)
	?NullFunction31@@YAXXZ @ 47 NONAME ; void __cdecl NullFunction31(void)
	?NullFunction32@@YAXXZ @ 48 NONAME ; void __cdecl NullFunction32(void)
	?NewL@CPushMessage@@SAPAV1@PAVHBufC8@@0@Z @ 49 NONAME ; public: static class CPushMessage * __cdecl CPushMessage::NewL(class HBufC8 *,class HBufC8 *)
	?NullFunction33@@YAXXZ @ 50 NONAME ; void __cdecl NullFunction33(void)
	?NullFunction34@@YAXXZ @ 51 NONAME ; void __cdecl NullFunction34(void)
	?NullFunction35@@YAXXZ @ 52 NONAME ; void __cdecl NullFunction35(void)
	?NullFunction36@@YAXXZ @ 53 NONAME ; void __cdecl NullFunction36(void)
	?NullFunction37@@YAXXZ @ 54 NONAME ; void __cdecl NullFunction37(void)
	?NullFunction38@@YAXXZ @ 55 NONAME ; void __cdecl NullFunction38(void)
	?NullFunction39@@YAXXZ @ 56 NONAME ; void __cdecl NullFunction39(void)
	?NullFunction40@@YAXXZ @ 57 NONAME ; void __cdecl NullFunction40(void)
	?NullFunction41@@YAXXZ @ 58 NONAME ; void __cdecl NullFunction41(void)
	?NullFunction42@@YAXXZ @ 59 NONAME ; void __cdecl NullFunction42(void)
	?NullFunction43@@YAXXZ @ 60 NONAME ; void __cdecl NullFunction43(void)
	?NullFunction44@@YAXXZ @ 61 NONAME ; void __cdecl NullFunction44(void)
	?NullFunction45@@YAXXZ @ 62 NONAME ; void __cdecl NullFunction45(void)
	?NullFunction46@@YAXXZ @ 63 NONAME ; void __cdecl NullFunction46(void)
	?NullFunction47@@YAXXZ @ 64 NONAME ; void __cdecl NullFunction47(void)
	?NullFunction48@@YAXXZ @ 65 NONAME ; void __cdecl NullFunction48(void)
	?NullFunction49@@YAXXZ @ 66 NONAME ; void __cdecl NullFunction49(void)
	?NullFunction50@@YAXXZ @ 67 NONAME ; void __cdecl NullFunction50(void)
	?NullFunction51@@YAXXZ @ 68 NONAME ; void __cdecl NullFunction51(void)
	?NullFunction52@@YAXXZ @ 69 NONAME ; void __cdecl NullFunction52(void)
	?NullFunction53@@YAXXZ @ 70 NONAME ; void __cdecl NullFunction53(void)
	?NullFunction54@@YAXXZ @ 71 NONAME ; void __cdecl NullFunction54(void)
	?NullFunction55@@YAXXZ @ 72 NONAME ; void __cdecl NullFunction55(void)
	?NullFunction56@@YAXXZ @ 73 NONAME ; void __cdecl NullFunction56(void)
	?NullFunction57@@YAXXZ @ 74 NONAME ; void __cdecl NullFunction57(void)
	?NullFunction58@@YAXXZ @ 75 NONAME ; void __cdecl NullFunction58(void)
	?NullFunction59@@YAXXZ @ 76 NONAME ; void __cdecl NullFunction59(void)
	?NullFunction60@@YAXXZ @ 77 NONAME ; void __cdecl NullFunction60(void)
	?NullFunction61@@YAXXZ @ 78 NONAME ; void __cdecl NullFunction61(void)
	?NullFunction62@@YAXXZ @ 79 NONAME ; void __cdecl NullFunction62(void)
	?NullFunction63@@YAXXZ @ 80 NONAME ; void __cdecl NullFunction63(void)
	?GetServerAddress@CPushMessage@@QBEHAAVTPtrC8@@@Z @ 81 NONAME ; public: int __thiscall CPushMessage::GetServerAddress(class TPtrC8 &)const 
	?NewL@CPushMessage@@SAPAV1@PAVHBufC8@@0E0@Z @ 82 NONAME ; public: static class CPushMessage * __cdecl CPushMessage::NewL(class HBufC8 *,class HBufC8 *,unsigned char,class HBufC8 *)
	?GetPushId@CPushMessage@@QBEHAAE@Z @ 83 NONAME ; public: int __thiscall CPushMessage::GetPushId(unsigned char &)const 
	?GetAppIdL@CPushMessage@@QAEHAAVTPtrC8@@AAH1@Z @ 84 NONAME ; int CPushMessage::GetAppIdL(class TPtrC8 &, int &, int &)
	?ParseMultiOctetInteger@TWapBinCodex@@SAHABVTDesC8@@AAH@Z @ 85 NONAME ; int TWapBinCodex::ParseMultiOctetInteger(class TDesC8 const &, int &)
	?MessageAllowed@CPushMessage@@QBEHXZ @ 86 NONAME ; int CPushMessage::MessageAllowed(void) const
	?SetMessageAllowed@CPushMessage@@QAEXH@Z @ 87 NONAME ; void CPushMessage::SetMessageAllowed(int)

